package org.ubicollab.service.pptviewer;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.ubicollab.core.service.proxy.ServiceProxyServer;
import org.ubicollab.service.ServiceLink;
import org.ubicollab.service.ServiceLinkRegisterer;

/* Note: Package org.ubicollab.service.proxy is currently marked as a optional bundle to import.
 * It is required either if sharing of service is enabled, or if transfer method
 * ServiceLink.TRANSFER_METHOD_HTTP is used anywhere.
 */
public class Activator implements BundleActivator {
	private BundleContext bundleContext;
	// TODO: Get setting shareService from a "place" accessible both for SDM and this instance. 
	private boolean shareService = false; 
	private PptService pptService;
	private ServiceProxyServer proxyServer;
	
	/**
	 * @see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
	 */
	public void start(BundleContext bundleContext) throws Exception {
		this.bundleContext = bundleContext;
		initPptService();
		registerPptService();
		
		if (shareService) {
			shareService();
		}
		
		Debug.print("Ready.");
	}

	private void initPptService() {
		int transferMethod = ServiceLink.TRANSFER_METHOD_DIRECT;
		//int transferMethod = ServiceLink.TRANSFER_METHOD_HTTP;
		pptService = new PptService(transferMethod);
	}

	private void registerPptService() {
		ServiceLinkRegisterer.registerOsgiService(
				bundleContext, pptService, PptService.class.getName());
	}
	
	private void shareService() {
		proxyServer = new ServiceProxyServer(
				pptService, PptService.SERVLET_ALIAS);
		proxyServer.start(bundleContext);
		Debug.print("Service shared.");
	}

	/**
	 * @see org.osgi.framework.BundleActivator#stop(org.osgi.framework.BundleContext)
	 */
	public void stop(BundleContext context) throws Exception {
		if (shareService && proxyServer.isRunning()) {
			proxyServer.stop();
		}
		Debug.print("Stopped.");
	}

}
