package org.ubicollab.service.pptviewer;

import java.io.IOException;

import org.ubicollab.service.Commands;
import org.ubicollab.service.ServiceLink;
import org.ubicollab.service.SettingsHandlerServiceLink;
import org.ubicollab.service.settings.ServiceSettings;

public class PptServiceLink implements ServiceLink {

	public static final String COMMAND_OPENPPT = "openPpt";
	private PptViewer pptViewer;
	private SettingsHandlerServiceLink settingsHandler;
	
	public PptServiceLink(ServiceSettings settings) {
		settingsHandler = new SettingsHandlerServiceLink(settings);
		this.pptViewer = new PptViewerImpl(settings);
	}
	
	/*
	 * (non-Javadoc)
	 * @see org.ubicollab.service.ServiceLinkReceiver#msgReceivedSynch(java.lang.String)
	 */
	// TODO: Handle concurrency? For now, a synchronized has been put on PptViewer.msgReceived(String msg); 
	public String msgReceived(String msg) {
		String settingsHandlerReply = settingsHandler.msgReceived(msg);
		
		if (settingsHandlerReply.equals(Commands.INVALID_COMMAND)) {
			return handleRequest(msg);
		} else {
			return settingsHandlerReply;
		}

	}

	private String handleRequest(String msg) {
		String command = parseCommand(msg);
		String urlToPptViewer = "noUrl";

		if (command.equals(COMMAND_OPENPPT)) {
			return commandIsOpenPpt(msg, urlToPptViewer);
		} else {
			return Commands.INVALID_COMMAND;
		}
	}

	/*
	 * Example message: "openPpt http://www.abc.com/abc.ppt".
	 * Will give result: openPpt
	 */
	private String parseCommand(String msg) {
		String command = getFirstWordOf(msg);
		return command;
	}

	private String getFirstWordOf(String msg) {
		String word = msg.substring(0, msg.indexOf(" "));
		return word;
	}
	
	private String commandIsOpenPpt(String msg, String urlToPptViewer) {
		try {
			String urlToPpt = getUrlFrom(msg);
			urlToPptViewer = pptViewer.openPpt(urlToPpt);
			return urlToPptViewer;
		} catch (IndexOutOfBoundsException e) {
			Debug.print("ERROR: Could not get URL from msg=" + msg);
			return Commands.FAILURE;
		} catch (IOException e) {
			e.printStackTrace();
			return Commands.FAILURE;
		}
	}	
	
	private String getUrlFrom(String msg) {
		String url = msg.substring(msg.indexOf(" ") + 1);
		return url;
	}

}
