package org.ubicollab.service.pptviewer;
/*
 * USAGE:
 * PptViewer myPptViewer = new PptViewer();
 * String pptCtrl = myPptViewer.openPpt("http://yngvark.com/files/MSIS.ppt");
 * System.out.println("URL to pptController: " + pptCtrl);
 * 
 * RESOURCES:
 * Tutorial "Sending a POST Request Using a URL":
 * http://www.exampledepot.com/egs/java.net/Post.html
*/

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;

import org.ubicollab.service.settings.ServiceSettings;

public class PptViewerImpl implements PptViewer {
	static final String URL_TO_PPT_APP_PROPERTY_NAME = "urlToPptViewerWebApp"; 
	private ServiceSettings settings;
	
	public PptViewerImpl(ServiceSettings settings) {
		this.settings = settings;
		setDefaultSettingsValues();
	}
	
	private void setDefaultSettingsValues() {
		if (settings.get(PptViewerImpl.URL_TO_PPT_APP_PROPERTY_NAME) == null) {
			settings.set(
					URL_TO_PPT_APP_PROPERTY_NAME,
					"http://192.168.1.109/ubicollab/services/pptViewer/");
		}
		
	}

	public String openPpt(String urlToPpt) throws IOException {
		URLConnection pptViewerHostConn = startPptViewerOnHost(urlToPpt);
		String urlToPptViewer = getUrlToPptViewerFrom(pptViewerHostConn);
	    return urlToPptViewer;
	}

	private URLConnection startPptViewerOnHost(String urlToPpt)
	throws MalformedURLException, IOException {
		/*
		URL pptViewerHostUrl = new URL(
				"?" +
				"action=viewPpt&url=" + urlToPpt);
		*/
		String urlToPptViewerWebApp = settings.get(URL_TO_PPT_APP_PROPERTY_NAME); 
		URL pptViewerHostUrl = new URL(
				urlToPptViewerWebApp + "?" +
				"action=viewPpt&url=" + urlToPpt);

		URLConnection pptViewerHostConn = pptViewerHostUrl.openConnection();
		return pptViewerHostConn;
	}

	private String getUrlToPptViewerFrom(URLConnection pptViewerHostConn) throws IOException {
		// Get the response
		BufferedReader responseReader = new BufferedReader(
				new InputStreamReader(pptViewerHostConn.getInputStream()));

		String htmlResponse = fetchHtmlResponseAsOneLine(responseReader);
		if (htmlResponse == null) {
			throw new RuntimeException(
			"Response from PptViewer host application was null");
		}

		String urlToClientWebApp = extractUrlFromResponse(htmlResponse);
		responseReader.close();

		return urlToClientWebApp;
	}

	private String fetchHtmlResponseAsOneLine(BufferedReader responseReader)
	throws IOException {
		String htmlResponse = "";
		String line;

		while ((line = responseReader.readLine()) != null) {
			htmlResponse += line; 
		}

		return htmlResponse;
	}

	/*
	 * Expected response from server is a one line HTML with a META refresh tag that
	 * redirects the client to another web page. This method returns the URL of the
	 * target web page.
	 * 
	 * Example:
	 * extractUrlFromResponse("<html><head><meta http-equiv='refresh'" + 
	 * 		"content='0;url=clientViewer.php?imagesDir=out_KE5LVOcv1E&imgNum=1&" +
	 * 		"client=true' /></head></html>"
	 * 		);
	 * ... will return clientViewer.php?imagesDir=out_KE5LVOcv1E&imgNum=1&client=true
	 * 
	 * @param htmlResponse	The string containing url=[something]'
	 * @return				The url of the redirected web page.
	 */
	private String extractUrlFromResponse(String htmlResponse) {
		int indexOfUrlStart = htmlResponse.indexOf("url=") + 4;
		int indexOfUrlEnd = htmlResponse.indexOf("'", indexOfUrlStart);

		if (indexOfUrlStart == -1 || indexOfUrlEnd == -1) {
			Debug.print("Could not etract URL from HTML response. Response:");
			Debug.print(htmlResponse);
			throw new RuntimeException("Could not etract URL from HTML response.");
		}

		String url = htmlResponse.substring(indexOfUrlStart, indexOfUrlEnd);
		return url;
	}

}
