package org.ubicollab.app.pptviewer;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.util.tracker.ServiceTracker;
import org.ubicollab.service.ServiceLink;
import org.ubicollab.service.ServiceLinkGetter;
import org.ubicollab.service.exception.InvalidServiceLinkException;
import org.ubicollab.service.pptviewer.PptService;
import org.ubicollab.view.servlet.GUIServlet;

import android.webkit.WebView;

import com.prosyst.mbs.android.application.ApplicationRegistry;

public class Activator implements BundleActivator {
	private static Activator instance = null;

	protected static GUIServlet guiServlet;

	// Android
	private ServiceTracker appRegTracker;
	private ApplicationRegistry appReg;
	private MyApplicationFactory fact;	
	public static BundleContext bundleContext;
	
	// PptViewer
	private WebView webView;
	private PptViewer pptViewer;
	
	public void start(BundleContext context) throws Exception {
		instance = this;
		bundleContext = context;
		PptService pptService = tryToGetPptService();
		pptViewer = new PptViewer(pptService);
		
		registerAppToAndroid();

		Debug.print("Ready.");
	}

	public void stop(BundleContext context) throws Exception {
		stopAppTracker();
		Debug.print("Stopped.");
	}

	public static Activator getInstance() {
		return instance;
	}

	private PptService tryToGetPptService() {
		try {
			return getPptService();
		} catch (InvalidServiceLinkException e) {
			e.printStackTrace();
			throw e;
		}
	}

	private PptService getPptService() throws InvalidServiceLinkException {
		ServiceLink pptServiceLink = ServiceLinkGetter.getOsgiService(
				bundleContext, PptService.class.getName());
		
		if (pptServiceLink instanceof PptService) {
			return (PptService) pptServiceLink;
		} else {
			throw new InvalidServiceLinkException(
					"Received a ServiceLink that was not a PptService.");
		}
	}
	
	public PptViewer getPptViewer() {
		return pptViewer;
	}
	
	private void registerAppToAndroid() {
		// Create application service tracker
		appRegTracker = new ServiceTracker(
				Activator.bundleContext,
				ApplicationRegistry.class.getName(),
				null);
		appRegTracker.open();
		appReg = (ApplicationRegistry) appRegTracker.getService();

		if (appReg != null) {
		    // The ApplicationFactory provides an Android UI of the bundle.
		    fact = new MyApplicationFactory();
		    fact.appInitialize();
		    // Register the ApplicationFactory using the OSGi ApplicationRegistry.
		    if (appReg.registerApplicationFactory(fact)) {
		    	// Debug.print("TRUE: A new type was registered");
		    } else {
		    	Debug.print("FALSE: Some supported \"types\" are already registered.");
		    }
		} else {
			Debug.print("ERROR: appReg service is null!");
		}
	}	

	private void stopAppTracker() {
		if (appReg != null) {
			// Unregister the ApplicationFactory
			if (fact != null) {
				appReg.unregisterApplicationFactory(fact);
			} else {
				Debug.print("ERROR: fact is null");
			}
		} else {
			Debug.print("ERROR: appReg is null");
		}
		
		if (appRegTracker != null) {
			// Close the service tracker for the ApplicationFactory
			appRegTracker.close();
		} else {
			Debug.print("ERROR: appRegTracker is null");
		}
	}
	
	public void setWebView(WebView webView) {
		this.webView = webView;
	}
	
	public WebView getWebView() {
		return webView;
	}

}

