package org.ubicollab.app.pptviewer;

import org.ubicollab.view.servlet.GUIServlet;

import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.view.View;

import com.prosyst.mbs.android.application.ActivityWrapper;
import com.prosyst.mbs.android.application.ApplicationFactory;
import com.prosyst.mbs.android.application.CallbackHandler;

public class MyApplicationFactory implements ApplicationFactory {
	public static final String APP_NAME = "PptViewer";
	private static final String RES_IMAGES_ICON_PROJECTOR =
		"/resources/HP-Projector-icon.png";
	static final String APP_TYPE = "org.ubicollab.app.pptviewer";
	private Bitmap icon;
	private boolean isAppInitialized = false;
	
	// This method is inherited from com.prosyst.mbs.android.application.ApplicationFactory.
	// It simply returns a GUI when the Bundle Activator starts the mBS activity.  
	public View createView(ActivityWrapper activityWrapper, Intent starter, 
			CallbackHandler callbackHandler) {
		View view = createGUIViewer(activityWrapper);
		return view;
	}
	
	public void appInitialize() {
		if (! isAppInitialized()) {
			createWebGUI();
			isAppInitialized = true;
		}
	}

	private boolean isAppInitialized() {
		return isAppInitialized;
	}

	private void createWebGUI() {
		Debug.print("Creating web GUI.");
		// Create HTML Pages.
		PageSelectPresentation pageViewPres = new PageSelectPresentation();
		PageViewPresentation pageLoadPres = new PageViewPresentation();
		PageMainMenu pageMainMenu = new PageMainMenu();
		pageMainMenu.addHtmlPageToMenu(pageViewPres, "View and control a presentation");
		
		// Create a GUI/viewer for the HTML pages.
		GUIServlet guiServlet = new GUIServlet("pptViewer", Activator.bundleContext); // registrerer servleten = lager en webside
		guiServlet.addHtmlPage(pageMainMenu);
		guiServlet.addHtmlPage(pageViewPres);
		guiServlet.addHtmlPage(pageLoadPres);
		Activator.guiServlet = guiServlet; 
		guiServlet.registerHttpServlet();
	}

	private View createGUIViewer(ActivityWrapper activityWrapper) {
		WebGUI guiViewer = new WebGUI(activityWrapper); // Use HTML GUI
		String guiUrl = getGuiUrl();
		View view = guiViewer.createView(guiUrl);
		return view;
	}

	private String getGuiUrl() {
		String httpPort = getOsgiHttpPort();
		String guiURL = "http://localhost:" + httpPort +
			"/" + "pptViewer/?" + GUIServlet.PAGE_PARAM_NAME + "=" + PageMainMenu.PAGE_ID;
		return guiURL;
	}
	

	private String getOsgiHttpPort() {
		return System.getProperty("org.osgi.service.http.port", "1149");
	}
	
	// This method provides a custom icon to represent the UI of this bundle
	public Bitmap getIcon() {
		if (icon == null) {
			icon = BitmapFactory.decodeStream(
					Activator.class.getResourceAsStream(RES_IMAGES_ICON_PROJECTOR));
		}
		return icon;
	}

	// This method specifies the main application type of the bundle
	public String getMainType() {
		return APP_TYPE;
	}

	//This method specifies the friendly name of this bundle. It will be available in 
	// the Android desktop under this name.
	public String getName() {
		return APP_NAME;
	}

	// This method returns the main application types supported by this bundle.
	public String[] getSuportedTypes() {    
		return new String[] {APP_TYPE};
	}
	
}
