package org.ubicollab.app.pptviewer;

import android.view.View;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.widget.LinearLayout;

import com.prosyst.mbs.android.application.ActivityWrapper;

public class WebGUI {
	private WebView webView;
	private ActivityWrapper activityWrapper;
	
	public WebGUI(ActivityWrapper activityWrapper) {
		this.activityWrapper = activityWrapper;
	}
	
	// @param url The URL for the layout's WebView to show. 
	public View createView(String urlToOpen) {
		View webView = createWebView(urlToOpen);
		loadUrlInWebView(urlToOpen);

		LinearLayout layout = new LinearLayout(activityWrapper);
		layout.addView(webView);
		
		return layout;
	}

	// Creates a WebView and opens the specified URL. 
	private WebView createWebView(String urlToOpen) {
		Debug.print("Creating a WebView and opens URL: " + urlToOpen);

		webView = new WebView(activityWrapper);
		setWebViewSettings();
		setWebView(webView);
		
        return webView;
	}

	private void loadUrlInWebView(String urlToOpen) {
		this.webView.loadUrl(urlToOpen);
	}
	

	private void setWebViewSettings() {
		// disabledWebViewErrorButEnableBrowsingHaltError(); // TODO: Find source of errors.
		webView.getSettings().setJavaScriptEnabled(true);
		webView.getSettings().setAllowFileAccess(true);
		// TODO: For Android 2.1, set zoom settings so that when page changes, the zoom
		// distance is not increased. I haven't figured out how to do that yet.
		// TODO: Why doesn't this work??? Every time I click a link, the page is zooming
		// out way too far.
		
		//PptViewer pptViewer = Activator.getInstance().getPptViewer();
		webView.getSettings().setDefaultZoom(WebSettings.ZoomDensity.FAR);
	}

	/*
	private void disabledWebViewErrorButEnableBrowsingHaltError() {
		// TODO: Find source of errors.
		// WebViewClient fetches events of WebView. However, I'm using it as a hack in order to
		// disable an error message from the WebView to the user. The error displays the following
		// each time page SelectPresentation is opened: "No network connection: Browser cannot load
		// "this page because there is no internet connection".
		
		// However, I have disabled this because setting an own WebViewClient disables the
		// possibility to zoom in and out by double clicking the window. The double clicking fixses
		// another bug where part the browser hangs (specifically, the previous/next button of
		// pptViewer is not possible to click on, and this is resolved by zooming out/in
		
		//WebViewClient webViewClient = new WebViewClientPpt();
		//webView.setWebViewClient(webViewClient);
		
	}
	*/

	private void setWebView(WebView webView) {
		Activator.getInstance().setWebView(webView);
	}

	/* 
	 * Shows a standard HTML error page.
	 * TODO: Show message in the web page some way (dynamic content stuff).
	 */
	public void showError(String message) {
		Debug.print("[GUI ERROR] " + message);
	}


}
