package org.ubicollab.core.sdm;

import java.util.Properties;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.util.tracker.ServiceTracker;
import org.ubicollab.core.sm.model.ISpaceManager;

/**
 * Starts the DomainManager and registers it as an OSGi service.
 * 
 * @author Yngvar Kristiansen
 */
public class Activator implements BundleActivator {
	private BundleContext bundleContext;
	private DomainManager domainManager;

	/**
	 * @see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
	 */
	public void start(BundleContext bundleContext) throws Exception {
		this.bundleContext = bundleContext;
		regDomainManagerToOsgi();
		
		//Debug.doInternalTests(DomainManagerImpl.getInstance());
		Debug.print("Ready.");
	}

	/**
	 * @see org.osgi.framework.BundleActivator#stop(org.osgi.framework.BundleContext)
	 */
	public void stop(BundleContext context) throws Exception {
		Debug.print("Stopped.");
		// OSGi automatically unregisters registered services when a bundle stops,
		// so there is no need to stop anything here.
	}

	/**
	 * Registers DomainManager as a web service.
	 * 
	 * @param domainManager The DomainManager instance to register.
	 */
	private void regDomainManagerToOsgi() {
		ISpaceManager spaceManager = getSpaceManager();

		domainManager = new DomainManagerImpl(bundleContext, spaceManager);

		Properties osgiServiceProperties = new Properties();
		osgiServiceProperties.put("Language", "English");
		bundleContext.registerService(
				DomainManager.class.getName(),
				domainManager, osgiServiceProperties
				);
	}

	private ISpaceManager getSpaceManager() {
		ISpaceManager spaceManager =
			(ISpaceManager) getOsgiService(ISpaceManager.class.getName());
		return spaceManager;
	}
	
	private Object getOsgiService(String className) {
		ServiceTracker serviceListTracker = getServiceTracker(className);
		Object serviceInstance = serviceListTracker.getService();
		
		return serviceInstance; 
	}

	private ServiceTracker getServiceTracker(String className) {
		ServiceTracker serviceListTracker = new ServiceTracker(bundleContext, className, null);
		serviceListTracker.open();
		
		return serviceListTracker;
	}


	/*
	 * @deprecated Not supported anymore. Origin was Kim-Steve Johnansen's DomainManager
	 * implementation. 
	 * 
	 * Register DomainManager as a web service.
	 *  
	 * @param domainManager The DomainManager instance to register.
	 */
	/*
	private void regDomainManagerAsWebService(DomainManager domainManager) {
		Properties webServiceProperties = new Properties();
		webServiceProperties.put("Language", "English");
		webServiceProperties.put("SOAP.service.name", GlobalSettings.SOAP_SERVICE_NAME);
		bundleContext.registerService(
				DomainManager.class.getName(),
				domainManager, webServiceProperties
				);
	}
	*/

}
