package org.ubicollab.core.sdm;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;

import org.ubicollab.service.ServiceProxy;

public class ProxyListContainer {
	private HashMap<Long, ServiceProxy> serviceList;
	
	public ProxyListContainer() {
		serviceList = new HashMap<Long, ServiceProxy>();
	}
	
	/**
	 * @param bundleId The bundleID of the Bundle to get.
	 * 
	 * @return The UbicollabService with the given bundleId.
	 * 
	 * @throws IllegalArgumentException if Bundle with bundleId wasn't found.
	 */
	public ServiceProxy get(Long bundleId)
	throws IllegalArgumentException
	{
		if (! serviceExists(bundleId)) {
			String errorMsg = "ERROR EXCEPTION in getService(...): No bundle with bundleId " +
				bundleId + " exists!";
			Debug.print(errorMsg);
			throw new IllegalArgumentException(errorMsg);
		} else {
			ServiceProxy ubiService = serviceList.get(bundleId);
			return ubiService;
		}
	}
	
	public Collection<ServiceProxy> getServices() {
		// Return a new collection in order to avoid tampering with the ServiceList/HashMap.
		Iterator<ServiceProxy> iter = serviceList.values().iterator();
		Collection<ServiceProxy> newCollection = new ArrayList<ServiceProxy>(); 
		
		while (iter.hasNext()) {
			newCollection.add(iter.next());
		}
		
		return newCollection;
	}
	
	public void put(ServiceProxy ubiService) {
		serviceList.put(ubiService.getBundleId(), ubiService);
	}
	
	public ServiceProxy remove(Long bundleId) {
		ServiceProxy removedUbiService = serviceList.remove(bundleId);
		if (removedUbiService == null) {
			throw new IllegalArgumentException("No UbicollabService with bundleId=" + bundleId +
					" exists.");
		}
		
		return removedUbiService;
	}
	
	public int size() {
		return serviceList.size();
	}

	public boolean serviceExists(long bundleId) {
		return serviceList.containsKey(bundleId);
	}
}
