package org.ubicollab.core.sdm;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleEvent;
import org.osgi.framework.BundleListener;
import org.ubicollab.core.sm.model.Space;
import org.ubicollab.service.ServiceLink;
import org.ubicollab.service.ServiceLinkGetter;
import org.ubicollab.service.ServiceProxy;
import org.ubicollab.service.ServiceProxyFactory;
import org.ubicollab.service.ServiceProxyFinder;
import org.ubicollab.service.ServiceType;

public class UbicollabBundleListener implements BundleListener {
	private DomainManager domainManager;
	private ProxyList serviceList;
	private Bundle bundleChanged;
	
	public UbicollabBundleListener(DomainManager domainManager, ProxyList serviceList) {
		this.domainManager = domainManager;
		this.serviceList = serviceList;
	}
	
	public void bundleChanged(BundleEvent event) {
		Bundle bundleChanged = event.getBundle();
		
		if (ServiceProxyFinder.isAnUbciollabService(bundleChanged)) {
			ubicollabServiceChanged(event);		
		}
	}

	private void ubicollabServiceChanged(BundleEvent event) {
		bundleChanged = event.getBundle();
		
		if (event.getType() == BundleEvent.INSTALLED) {
			Debug.print("ubicollabServiceChanged: addUbicollabServiceFrom");
			addServiceProxy();
		} else if (event.getType() == BundleEvent.STARTED) {
			Debug.print("setServiceLink");
			setServiceLink();
		} else if (event.getType() == BundleEvent.UNINSTALLED) {
			Debug.print("ubicollabServiceChanged: tryToRemoveBundle");
			tryToRemoveBundle();
		} else if (event.getType() == BundleEvent.UPDATED) {
			Debug.print("ubicollabServiceChanged: updateUbicollabServiceWith");
			updateServiceProxySettingsWithSettingsFrom();
		}
	}

	private void setServiceLink() {
		long bundleId = bundleChanged.getBundleId();
		ServiceProxy proxyStarted = domainManager.getServices(bundleId);
		ServiceLink serviceLinkFound = ServiceLinkGetter.searchForServiceLink(bundleChanged);
		proxyStarted.setServiceLink(serviceLinkFound);
		Debug.print("Setting ServiceLink to " + serviceLinkFound);
	}

	private void updateServiceProxySettingsWithSettingsFrom() {
		Log log = Log.getInstance();

		try {
			tryToUpdateServiceProxySettingsWithSettingsFrom();
		} catch (IllegalArgumentException e) {
			String errorMsg = "Could not update bundle wth bundleId=" +
			bundleChanged.getBundleId() + ". Error: " + e.getMessage();
			log.writeToLog(errorMsg, Log.ERROR);
		}

	}

	private void tryToUpdateServiceProxySettingsWithSettingsFrom()
	throws IllegalArgumentException {
		ServiceProxy updatedService =
			ServiceProxyFactory.createUbicollabServiceFrom(bundleChanged);
		
		long newBundleId = updatedService.getBundleId();
		String newFriendlyName = updatedService.getName();
		Space newSpace = updatedService.getSpace();
		ServiceType newType = updatedService.getType();
		String newDescription = updatedService.getDescription();
		
		domainManager.updateServiceProperties(
				newBundleId,
				newFriendlyName,
				newSpace,
				newType,
				newDescription);
	}

	private void tryToRemoveBundle() {
		try {
			removeBundle();
		} catch (IllegalArgumentException e) {
			Debug.print("WARNING: BundleListener was notified of UNINSTALLED bundle, but " +
					"bundle could not be removed because: " + e.getMessage());
			e.printStackTrace();
		}
	}

	private void removeBundle() {
		serviceList.remove(bundleChanged.getBundleId());
	}

	private void addServiceProxy() {
		ServiceProxy ubiService =
			ServiceProxyFactory.createUbicollabServiceFrom(bundleChanged);
		serviceList.put(ubiService);
	}

}
