package org.ubicollab.core.sdm.view.android;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.util.tracker.ServiceTracker;

import com.prosyst.mbs.android.application.ApplicationRegistry;

public class Activator implements BundleActivator {
	// Android
	private ServiceTracker appRegTracker;
	private ApplicationRegistry appReg;
	private MyApplicationFactory fact;	
	public static BundleContext bundleContext;
	
	/*
	 * This method triggers the UI (a simple text view) in the Android environment, in
	 * particular in the mBS OSGi runtime activity. 
	 */
	public void start(BundleContext context) throws Exception {
		Debug.print("Starting bundle");
		bundleContext = context;
		
		// Start Android GUI. 
		startGUI(context);
		
		Debug.print("Ready.");
	}
	
	public void stop(BundleContext context) throws Exception {
		Debug.print("Stopping the GUI.");

		// Stop the Android GUI.
		stopAppTracker();
	}

	private void startGUI(BundleContext bc) {
		// Create application service tracker
		appRegTracker = new ServiceTracker(bc, ApplicationRegistry.class.getName(), null);
		appRegTracker.open();
		appReg = (ApplicationRegistry) appRegTracker.getService();

		if (appReg != null) {
		    // The ApplicationFactory provides an Android UI of the bundle.
		    fact = new MyApplicationFactory();
	    	
		    // Register the ApplicationFactory using the OSGi ApplicationRegistry.
		    if (appReg.registerApplicationFactory(fact)) {
		    	Debug.print("TRUE: A new type was registered");
		    } else {
		    	Debug.print("FALSE: Some supported \"types\" are already registered.");
		    }
		} else {
			Debug.print("ERROR: appReg service is null!");
		}
	}	

	private void stopAppTracker() {
		if (appReg != null) {
			// Unregister the ApplicationFactory
			Debug.print("Unregistering the ApplicationFactory");
			if (fact != null) {
				appReg.unregisterApplicationFactory(fact);
			} else {
				Debug.print("ERROR: fact is null");
			}
		} else {
			Debug.print("ERROR: appReg is null");
		}
		
		if (appRegTracker != null) {
			// Close the service tracker for the ApplicationFactory
			Debug.print("Closing appRegTracker");
			appRegTracker.close();
		} else {
			Debug.print("ERROR: appRegTracker is null");
		}
	}
	


}

