package org.ubicollab.core.sdm.view.servlet;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.util.tracker.ServiceTracker;
import org.ubicollab.core.sdm.DomainManager;
import org.ubicollab.core.sm.model.ISpaceManager;

public class Activator implements BundleActivator {
	private static BundleContext bundleContext;
	private static DomainManager domainManager;
	private static ISpaceManager spaceManager;
	
	private SDMServlet sdmServlet;
	
	/*
	 * This method triggers the UI (a simple text view) in the Android environment, in
	 * particular in the mBS OSGi runtime activity. 
	 */
	public void start(BundleContext bundleContext) throws Exception {
		Activator.bundleContext = bundleContext;
		createGuiServlet(bundleContext);
		
		Debug.print("Ready.");
	}
	
	public void stop(BundleContext context) throws Exception {
		sdmServlet.unregisterHttpServlet();
		Debug.print("Stopped.");
	}	

	private void createGuiServlet(BundleContext bundleContext) {
		Debug.print("Creating web GUI.");
		domainManager = getDomainManagerFromOsgi();
		spaceManager = getSpaceManagerFromOsgi();
		
		sdmServlet = new SDMServlet();
		sdmServlet.registerHttpServlet();
	}

	private DomainManager getDomainManagerFromOsgi() {
		DomainManager domainManager =
			(DomainManager) getOsgiService(DomainManager.class.getName());
		return domainManager;
	}

	private Object getOsgiService(String className) {
		ServiceTracker serviceListTracker = getServiceTracker(className);
		Object serviceInstance = serviceListTracker.getService();
		
		return serviceInstance; 
	}

	private ServiceTracker getServiceTracker(String className) {
		ServiceTracker serviceListTracker = new ServiceTracker(bundleContext, className, null);
		serviceListTracker.open();
		
		return serviceListTracker;
	}

	private ISpaceManager getSpaceManagerFromOsgi() {
		ISpaceManager spaceManager =
			(ISpaceManager) getOsgiService(ISpaceManager.class.getName());
		return spaceManager;
	}
	
	public static BundleContext getBundleContext() {
		return bundleContext;
	}
	
	public static DomainManager getDomainManager() {
		return domainManager;
	}
	
	public static ISpaceManager getSpaceManager() {
		return spaceManager;
	}

}

