package org.ubicollab.core.sdm.view.servlet.form;

import java.util.ArrayList;
import java.util.Enumeration;

import org.ubicollab.service.settings.ServiceSettings;

public class ServiceSettingsFormBuilder {
	static final String FORM_ELEMENT_PREFIX = "ubi_";
	static final String PARAM_NAME_SEPARATOR = "%)]#";
	
	public static HTMLForm buildHtmlFormFrom(ServiceSettings settings)
	{
		ArrayList<LabeledTextField> textFields =
			convertServiceSettingsToTextFields(settings);
		HTMLForm htmlForm = createHtmlForm(textFields);
		
		return htmlForm;
	}

	private static ArrayList<LabeledTextField> convertServiceSettingsToTextFields(ServiceSettings settings)
	{
		ArrayList<LabeledTextField> textFields = new ArrayList<LabeledTextField>();
		
		Enumeration<?> enumeration = settings.getElements();
		while (enumeration.hasMoreElements()) {
			String label = enumeration.nextElement().toString();
			String name = getAttributeNameFromVariableName(label);
			String value = settings.get(label);
			
			LabeledTextField textField = new LabeledTextField(label, name, value);
			textFields.add(textField);
		}
		
		return textFields;
	}

	private static HTMLForm createHtmlForm(ArrayList<LabeledTextField> textFields) {
		HTMLForm htmlForm = new HTMLForm();
		
		for (LabeledTextField textField : textFields) {
			htmlForm.addTextField(textField);
		}
		
		return htmlForm;
	}

	static String getAttributeNameFromVariableName(String variableName) {
		return FORM_ELEMENT_PREFIX + PARAM_NAME_SEPARATOR + variableName;
	}
	
	public static String getPropertyNameFromAttributeName(String attribName) {
		String prefix = FORM_ELEMENT_PREFIX + PARAM_NAME_SEPARATOR;
		int varNameBeginIndex = prefix.length();
		
		String varName = attribName.substring(varNameBeginIndex);
		return varName;
	}
	
	public static boolean isServiceSettingAttribute(String attribute) {
		String validPrefix = FORM_ELEMENT_PREFIX + PARAM_NAME_SEPARATOR;
		int validPrefixLength = validPrefix.length();
		
		try {
			String prefix = attribute.substring(0, validPrefixLength);
			return prefix.equals(validPrefix);
		} catch (IndexOutOfBoundsException e) {
			return false;
		}
		
	}
	
	/*
	private static String getUniqueFormName() {
		return FORM_ELEMENT_PREFIX + getUniqueString();
	}
	
	private static String getUniqueString() {
		return UniqueStringFactory.createUniqueString();
	}
	*/
	
}
