package org.ubicollab.core.sdm.view.servlet.pages;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import org.ubicollab.core.sdm.DomainManager;
import org.ubicollab.core.sdm.view.servlet.Activator;
import org.ubicollab.core.sdm.view.servlet.SDMServlet;
import org.ubicollab.core.sm.model.Space;
import org.ubicollab.service.ServiceProxy;
import org.ubicollab.view.servlet.LinkedHTMLTemplate;

public class PageCategrByPlace extends LinkedHTMLTemplate {

	public static final String PAGE_ID = "PageCategrByPlace";
	
	private DomainManager domainManager;
	
	public PageCategrByPlace() {
		this.domainManager = Activator.getDomainManager();
	}
	
	@Override
	protected String getTitle() {
		return SDMServlet.SDM_PAGE_TITLE;
	}

	@Override
	protected String getSubTitle() {
		return "Viewing services categorized by their place";
	}

	public String getPageId() {
		return PAGE_ID;
	}

	@Override
	protected String getHTMLBody() {
		String html = "";

		html += createLinksToPlaces();
		html += getGoBackLink();

		return html;
	}

	private String createLinksToPlaces() {
		Map<Long, Space> spacesUsedByServices = getSpacesUsedByServices();
		String htmlLinks = createLinksToPageViewServiceFrom(spacesUsedByServices);
		
		return htmlLinks;
	}

	private Map<Long, Space> getSpacesUsedByServices() {
		Iterator<ServiceProxy> servIter = domainManager.getServices().iterator();
		Map<Long, Space> spacesUsedByServices = new HashMap<Long, Space>();
		
		while (servIter.hasNext()) {
			ServiceProxy currentServProxy = servIter.next();
			Space currentSpace = currentServProxy.getSpace();
			
			spacesUsedByServices.put(currentSpace.getId(), currentSpace);
		}
		
		return spacesUsedByServices;
	}

	private String createLinksToPageViewServiceFrom(Map<Long, Space> spacesUsedByServices) {
		String html = "";
		html += "<p>";
		
		Iterator<Space> spaceIter = spacesUsedByServices.values().iterator();
		while (spaceIter.hasNext()) {
			Space currentSpace = spaceIter.next();
			html += createLinkToPageViewServiceFrom(currentSpace);
		}
		
		html += "</p>";
		
		return html;
	}

	private String createLinkToPageViewServiceFrom(Space space) {
		String urlToPageViewServices = getUrlTo(PageViewServicesInPlace.PAGE_ID);
		String getParamsForSpaceId =
			PageViewServicesInPlace.PARAM_SPACE_ID_TO_VIEW + "=" + space.getId();
		
		String html =
			"<a href='" + urlToPageViewServices + "&" + getParamsForSpaceId + "'>" +
			space.getName() +
			"</a><br />";
		
		return html;
	}

	private String getGoBackLink() {
		String html = "<p><a href='" + getUrlTo(PageMainMenu.PAGE_ID) + "'>" +
			"Go back</a></p>";
		
		return html;
	}

}
