package org.ubicollab.core.sdm.view.servlet.pages;

import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

import org.ubicollab.core.sdm.DomainManager;
import org.ubicollab.core.sdm.view.servlet.Activator;
import org.ubicollab.core.sdm.view.servlet.SDMServlet;
import org.ubicollab.service.ServiceProxy;
import org.ubicollab.service.ServiceType;
import org.ubicollab.view.servlet.LinkedHTMLTemplate;

public class PageCategrByType extends LinkedHTMLTemplate {

	public static final String PAGE_ID = "PageCategrByType";
	
	private DomainManager domainManager;
	
	public PageCategrByType() {
		this.domainManager = Activator.getDomainManager();
	}
	
	@Override
	protected String getTitle() {
		return SDMServlet.SDM_PAGE_TITLE;
	}

	@Override
	protected String getSubTitle() {
		return "Viewing services categorized by their type";
	}

	public String getPageId() {
		return PAGE_ID;
	}

	@Override
	protected String getHTMLBody() {
		String html = "";

		html += createLinksToTypes();
		html += getGoBackLink();

		return html;
	}

	private String createLinksToTypes() {
		Set<ServiceType> typesUsedByServices = getTypesUsedByServices();
		String htmlLinks = createLinksToPageViewServiceFrom(typesUsedByServices);
		
		return htmlLinks;
	}

	private Set<ServiceType> getTypesUsedByServices() {
		Iterator<ServiceProxy> typeIter = domainManager.getServices().iterator();
		Set<ServiceType> typesUsedByServices = new HashSet<ServiceType>();
		
		while (typeIter.hasNext()) {
			ServiceProxy currentServProxy = typeIter.next();
			ServiceType currentType = currentServProxy.getType();
			typesUsedByServices.add(currentType);
		}
		
		return typesUsedByServices;
	}

	private String createLinksToPageViewServiceFrom(Set<ServiceType> typesUsedByServices) {
		String html = "";
		html += "<p>";
		
		Iterator<ServiceType> typeIter = typesUsedByServices.iterator();
		while (typeIter.hasNext()) {
			ServiceType currentType = typeIter.next();
			html += createLinkToPageViewServiceFrom(currentType);
		}
		
		html += "</p>";
		
		return html;
	}

	private String createLinkToPageViewServiceFrom(ServiceType type) {
		String urlToPageViewServices = getUrlTo(PageViewServicesWithType.PAGE_ID);
		String getParamsForType =
			PageViewServicesWithType.PARAM_TYPE_NAME_TO_VIEW + "=" + type.getName();
		
		String html =
			"<a href='" + urlToPageViewServices + "&" + getParamsForType + "'>" +
			type.getName() +
			"</a><br />";
		
		return html;
	}

	private String getGoBackLink() {
		String html = "<p><a href='" + getUrlTo(PageMainMenu.PAGE_ID) + "'>" +
			"Go back</a></p>";
		
		return html;
	}

}
