package org.ubicollab.core.sdm.view.servlet.pages;

import org.ubicollab.core.sdm.view.servlet.SDMServlet;
import org.ubicollab.core.sdm.view.servlet.form.HTMLForm;
import org.ubicollab.core.sdm.view.servlet.form.ServiceSettingsFormBuilder;
import org.ubicollab.service.Commands;
import org.ubicollab.service.ServiceProxy;
import org.ubicollab.service.exception.InvalidXMLException;
import org.ubicollab.service.settings.ServiceSettings;
import org.ubicollab.view.servlet.GUIServlet;
import org.ubicollab.view.servlet.LinkedHTMLTemplate;

public class PageEditServiceProperties extends LinkedHTMLTemplate {

	public static final String PAGE_ID = "PageEditServiceProperties";
	
	private HTMLBuilder htmlBuilder;
	private ServiceProxy selectedProxy;
	private String settingsXmlReply;
	private ServiceSettings serviceSettings;
	private HTMLForm editSettingsForm;
	
	public PageEditServiceProperties() {
	}

	protected void init() {
		getServiceProxy(); // Should be first method call.
		initHtmlBuilder();
		buildPage();
	}

	private void initHtmlBuilder() {
		htmlBuilder = new HTMLBuilder();
	}

	private void buildPage() {
		addHeader();
		
		getServiceSettings();
		addServiceSettingsForm();
		
		addFooter();
	}

	private void addHeader() {
		htmlBuilder.addHtml("<h3>" + selectedProxy.getName() + "</h3>");
	}

	private void getServiceProxy() {
		selectedProxy = ReferencedServices.getLastReferencedServiceProxy();
	}

	private void getServiceSettings() {
		try {
			tryToGetServiceSettings();
		} catch (InvalidXMLException e) {
			htmlBuilder.addHtml("Service returned invalid settings.");
			e.printStackTrace();
		} catch (Exception e) {
			htmlBuilder.addLine("Service error: " + e.getMessage());
			e.printStackTrace();
		}
	}

	private void tryToGetServiceSettings() throws InvalidXMLException, Exception {
		settingsXmlReply = selectedProxy.getServiceLink().msgReceived(Commands.GET_SETTINGS);
	}
	

	private void addServiceSettingsForm() {
		buildSettingsForm();
		addFormToPage();
	}

	private void buildSettingsForm() {
		if (settingsXmlReply.length() == 0) {
			buildEmptyPage();
		} else {
			buildSettingsFormWithSettings();
		}
	}

	private void buildEmptyPage() {
		htmlBuilder.addLine("Service has no settings.");
	}

	private void buildSettingsFormWithSettings() {
		getServiceSettingsFromXml();
		buildSettingsFormFromServiceSettings();
	}

	private void getServiceSettingsFromXml() {
		serviceSettings = new ServiceSettings(settingsXmlReply);
	}

	private void buildSettingsFormFromServiceSettings() {
		buildFormWithFormBuilder();
		setFormSettings();
	}

	private void buildFormWithFormBuilder() {
		editSettingsForm = ServiceSettingsFormBuilder.buildHtmlFormFrom(serviceSettings);
	}

	private void setFormSettings() {
		editSettingsForm.setMethod(HTMLForm.METHOD_GET);
		
		String urlTopageSaveServiceProperties = getUrlTo(PageSaveServiceProperties.PAGE_ID);
		editSettingsForm.setAction(urlTopageSaveServiceProperties);
		editSettingsForm.addHiddenField(GUIServlet.PAGE_PARAM_NAME, PageSaveServiceProperties.PAGE_ID);
	}

	private void addFormToPage() {
		String formHtml = editSettingsForm.getHtml();
		htmlBuilder.addHtml(formHtml);
	}
	
	private void addFooter() {
		htmlBuilder.addSeparatedLink(getUrlTo(PageViewServiceActions.PAGE_ID), "Go back");
	}
	
	@Override
	protected String getTitle() {
		return SDMServlet.SDM_PAGE_TITLE;
	}

	@Override
	protected String getSubTitle() {
		return "Edit service properties";
	}

	public String getPageId() {
		return PAGE_ID;
	}

	@Override
	protected String getHTMLBody() {
		return htmlBuilder.getHtml();
	}

}
