package org.ubicollab.core.sdm.view.servlet.pages;

import java.util.Comparator;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Set;
import java.util.TreeSet;

import org.ubicollab.core.sdm.view.servlet.SDMServlet;
import org.ubicollab.view.servlet.HTMLPage;
import org.ubicollab.view.servlet.LinkedHTMLTemplate;

public class PageMainMenu extends LinkedHTMLTemplate {
	
	public static final String PAGE_ID = "MainMenu";
	
	private HashMap<HTMLPage, String> menuItems;
	
	public PageMainMenu() {
		this.menuItems = new HashMap<HTMLPage, String>();
	}
	
	@Override
	protected String getTitle() {
		return SDMServlet.SDM_PAGE_TITLE;
	}

	@Override
	protected String getSubTitle() {
		return "Main menu";
	}

	public String getPageId() {
		return PAGE_ID;
	}
	
	@Override
	protected String getHTMLBody() {
		String content = "";
		content += "<p>";
		content += getHtmlMenu();
		content += "</p>";
		return content;
	}
	
	private String getHtmlMenu() {
		String htmlMenu = "";
		Iterator<HTMLPage> iterator = getIteratorForHtmlMenu();
		
		while (iterator.hasNext()) {
			HTMLPage htmlPage = iterator.next();
			htmlMenu += getMenuItemHtml(htmlPage);
		}
		
		htmlMenu += getCustomLinks();

		return htmlMenu;
	}

	private Iterator<HTMLPage> getIteratorForHtmlMenu() {
		Set<HTMLPage> menuItemsKeySet = menuItems.keySet();
		TreeSet<HTMLPage> sortedMenuItems = new TreeSet<HTMLPage>(getHtmlPageComparator());
		sortedMenuItems.addAll(menuItemsKeySet);
		
		Iterator<HTMLPage> iterator = sortedMenuItems.iterator();
		return iterator;
	}
	
	private Comparator<HTMLPage> getHtmlPageComparator() {
		Comparator<HTMLPage> htmlPageComp = new Comparator<HTMLPage>() {

			public int compare(HTMLPage pageA, HTMLPage pageB) {
				return pageA.getPageId().compareTo(pageB.getPageId());
			}
		};
		
		return htmlPageComp;
	}
	
	private String getCustomLinks() {
		String customLinks = "";
		customLinks += "<a href='/junit'>JUnit overview</a><br />";
		
		return customLinks;
	}

	private String getMenuItemHtml(HTMLPage htmlPage) {
		String htmlPageId = htmlPage.getPageId();
		String description = menuItems.get(htmlPage);
		String htmlMenuItem = "<a href='" + getUrlTo(htmlPageId) + "'>" +
			description + "</a><br/>";
		
		return htmlMenuItem;
	}

	public void addHtmlPageToMenu(HTMLPage htmlPage, String description) {
		menuItems.put(htmlPage, description);
	}

}
