package org.ubicollab.core.sdm.view.servlet.pages;

import java.io.IOException;
import java.util.Iterator;
import java.util.Map;
import java.util.Properties;

import javax.servlet.http.HttpServletRequest;

import org.ubicollab.core.sdm.view.servlet.SDMServlet;
import org.ubicollab.core.sdm.view.servlet.form.ServiceSettingsFormBuilder;
import org.ubicollab.service.Commands;
import org.ubicollab.service.ServiceProxy;
import org.ubicollab.service.settings.ServiceSettings;
import org.ubicollab.view.servlet.LinkedHTMLTemplate;

public class PageSaveServiceProperties extends LinkedHTMLTemplate {

	public static final String PAGE_ID = "PageSaveServiceProperties";
	
	private HTMLBuilder htmlBuilder;
	private ServiceProxy selectedProxy;
	private HttpServletRequest httpRequest;
	private ServiceSettings settingsToSave;
	
	public PageSaveServiceProperties() {
	}
	
	protected void init() {
		try {
			// TODO: Error handling if requestedServiceProxy is null
			getServiceProxy();  // Should be first method call.
			initHtmlBuilder();
			buildPage();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	private void initHtmlBuilder() {
		htmlBuilder = new HTMLBuilder();
	}

	private void buildPage() {
		addHeader();
		readHttpRequest();
		saveSettings();
		viewSuccessMessage();
		addFooter();
	}

	private void addHeader() {
		htmlBuilder.addHtml("<h3>" + selectedProxy.getName() + "</h3>");
	}

	private void getServiceProxy() {
		selectedProxy = ReferencedServices.getLastReferencedServiceProxy();
	}

	private void readHttpRequest() {
		settingsToSave = new ServiceSettings();
		httpRequest = getHttpRequest();
				
		Map<Object, Object> paramMap = httpRequest.getParameterMap();
		
		Iterator<?> iter = paramMap.keySet().iterator();
		
		while (iter.hasNext()) {
			String attributeName = iter.next().toString();
			addPropertyToRequestData(attributeName);
		}
		
	}

	private void addPropertyToRequestData(String attributeName) {
		if (ServiceSettingsFormBuilder.isServiceSettingAttribute(attributeName)) {
			addValidPropertyToRequestData(attributeName);
		}
	}

	private void addValidPropertyToRequestData(String attributeName) {
		String propertyName =
			ServiceSettingsFormBuilder.getPropertyNameFromAttributeName(attributeName);
		String value = httpRequest.getParameter(attributeName).toString();
		settingsToSave.set(propertyName, value);
	}

	private void saveSettings() {
		try {
			String settingsXml = settingsToSave.toXml();
			String saveCommand = Commands.buildCommand(Commands.SET_SETTINGS, settingsXml);
			selectedProxy.getServiceLink().msgReceived(saveCommand);
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
			throw new RuntimeException("Unknown IO exception when getting XML settings.");
		}
	}

	private void viewSuccessMessage() {
		htmlBuilder.addHtml("Settings saved!");
	}

	private void addFooter() {
		htmlBuilder.addSeparatedLink(getUrlTo(PageViewServiceActions.PAGE_ID), "Go back");
	}
	
	@Override
	protected String getTitle() {
		return SDMServlet.SDM_PAGE_TITLE;
	}

	@Override
	protected String getSubTitle() {
		return "Edit service properties";
	}

	public String getPageId() {
		return PAGE_ID;
	}

	@Override
	protected String getHTMLBody() {
		return htmlBuilder.getHtml();
	}

}
