package org.ubicollab.core.sdm.view.servlet.pages;

import org.ubicollab.core.sdm.DomainManager;
import org.ubicollab.core.sdm.view.servlet.Activator;
import org.ubicollab.core.sdm.view.servlet.SDMServlet;
import org.ubicollab.service.ServiceProxy;
import org.ubicollab.view.servlet.LinkedHTMLTemplate;

public class PageStartServiceAction extends LinkedHTMLTemplate  {

	public static final String PAGE_ID = "PageStartServiceAction";
	
	private DomainManager domainManager;
	private ServiceProxy serviceProxyToStart; 
	private boolean serviceWasStarted;
	private String htmlReply = "";
	
	public PageStartServiceAction() {
		this.domainManager = Activator.getDomainManager();
	}
	
	@Override
	protected void init() {
		getServiceProxy();
		stopServiceProxy();
		createHtmlReply();
	}

	private void getServiceProxy() {
		serviceProxyToStart = ReferencedServices.getLastReferencedServiceProxy();
	}

	private void stopServiceProxy() {
		serviceWasStarted = domainManager.startService(serviceProxyToStart.getBundleId());
	}	

	private void createHtmlReply() {
		if (serviceWasStarted)
			serviceWasStarted();
		else
			serviceWasNotStarted();
	}
	
	private void serviceWasStarted() {
		htmlReply = HTMLBuilder.createRedirectAsJavascript(getUrlTo(PageViewServiceActions.PAGE_ID));
	}

	private void serviceWasNotStarted() {
		htmlReply = "Service could not be started.<br/>";
		addGoBackLink();
	}

	private void addGoBackLink() {
		htmlReply += "<p><a href='" + getUrlTo(PageCategrByType.PAGE_ID) + "'>" +
			"Go back</a></p>";
	}

	@Override
	protected String getTitle() {
		return SDMServlet.SDM_PAGE_TITLE;
	}

	@Override
	protected String getSubTitle() {
		return "Starting service";
	}

	public String getPageId() {
		return PAGE_ID;
	}

	@Override
	protected String getHTMLBody() {
		return htmlReply;
	}

}
