package org.ubicollab.core.sdm.view.servlet.pages;

import org.ubicollab.core.sdm.DomainManager;
import org.ubicollab.core.sdm.view.servlet.Activator;
import org.ubicollab.core.sdm.view.servlet.SDMServlet;
import org.ubicollab.service.ServiceProxy;
import org.ubicollab.view.servlet.LinkedHTMLTemplate;

public class PageStopServiceAction extends LinkedHTMLTemplate  {

	public static final String PAGE_ID = "PageStopServiceAction";
	
	private DomainManager domainManager;
	private ServiceProxy serviceProxyToStop;
	private boolean serviceWasStopped;
	private String htmlReply = "";
	
	public PageStopServiceAction() {
		this.domainManager = Activator.getDomainManager();
	}
	
	@Override
	protected void init() {
		getServiceProxy();
		stopServiceProxy();
		createHtmlReply();
	}

	private void getServiceProxy() {
		serviceProxyToStop = ReferencedServices.getLastReferencedServiceProxy();
	}

	private void stopServiceProxy() {
		serviceWasStopped = domainManager.stopService(serviceProxyToStop.getBundleId());
	}
	

	private void createHtmlReply() {
		if (serviceWasStopped)
			serviceWasStopped();
		else
			serviceWasNotStopped();
	}
	
	private void serviceWasStopped() {
		htmlReply = HTMLBuilder.createRedirectAsJavascript(getUrlTo(PageViewServiceActions.PAGE_ID));
	}

	private void serviceWasNotStopped() {
		htmlReply = "Service could not be stopped.<br/>";
		addGoBackLink();
	}

	private void addGoBackLink() {
		htmlReply += "<p><a href='" + getUrlTo(PageCategrByType.PAGE_ID) + "'>" +
			"Go back</a></p>";
	}

	@Override
	protected String getTitle() {
		return SDMServlet.SDM_PAGE_TITLE;
	}

	@Override
	protected String getSubTitle() {
		return "Stopping service";
	}

	public String getPageId() {
		return PAGE_ID;
	}

	@Override
	protected String getHTMLBody() {
		return htmlReply;
	}

}
