package org.ubicollab.core.sdm.view.servlet.pages;

import org.ubicollab.core.sdm.DomainManager;
import org.ubicollab.core.sdm.view.servlet.Activator;
import org.ubicollab.core.sdm.view.servlet.SDMServlet;
import org.ubicollab.service.ServiceProxy;
import org.ubicollab.view.servlet.LinkedHTMLTemplate;

public class PageUninstallServiceAction extends LinkedHTMLTemplate  {

	public static final String PAGE_ID = "PageUninstallServiceAction";
	
	private DomainManager domainManager;
	private ServiceProxy serviceProxyToStart; 
	private boolean serviceWasUninstalled;
	private String htmlReply = "";
	
	public PageUninstallServiceAction() {
		this.domainManager = Activator.getDomainManager();
	}
	
	@Override
	protected void init() {
		getServiceProxy();
		uninstallServiceProxy();
		checkIfServiceWasUninstalled();
	}

	private void getServiceProxy() {
		serviceProxyToStart = ReferencedServices.getLastReferencedServiceProxy();
	}

	private void uninstallServiceProxy() {
		serviceWasUninstalled = domainManager.removeService(serviceProxyToStart.getBundleId());
	}
	

	private void checkIfServiceWasUninstalled() {
		if (serviceWasUninstalled)
			serviceWasUninstalled();
		else
			serviceWasNotUninstalled();
	}
	
	private void serviceWasUninstalled() {
		htmlReply = HTMLBuilder.createRedirectAsJavascript(getUrlTo(PageMainMenu.PAGE_ID));
	}

	private void serviceWasNotUninstalled() {
		htmlReply = "Service could not be uninstalled.<br/>";
		addGoBackLink();
	}

	private void addGoBackLink() {
		htmlReply += "<p><a href='" + getUrlTo(PageCategrByType.PAGE_ID) + "'>" +
			"Go back</a></p>";
	}

	@Override
	protected String getTitle() {
		return SDMServlet.SDM_PAGE_TITLE;
	}

	@Override
	protected String getSubTitle() {
		return "Uninstalled service";
	}

	public String getPageId() {
		return PAGE_ID;
	}

	@Override
	protected String getHTMLBody() {
		return htmlReply;
	}

}
