package org.ubicollab.core.sdm.view.servlet.pages;

import javax.servlet.http.HttpServletRequest;

import org.osgi.framework.Bundle;
import org.ubicollab.core.sdm.DomainManager;
import org.ubicollab.core.sdm.view.servlet.Activator;
import org.ubicollab.core.sdm.view.servlet.Debug;
import org.ubicollab.core.sdm.view.servlet.SDMServlet;
import org.ubicollab.service.ServiceProxy;
import org.ubicollab.service.exception.NoServiceProxyExistsException;
import org.ubicollab.view.servlet.LinkedHTMLTemplate;

public class PageViewServiceActions extends LinkedHTMLTemplate {

	public static final String PAGE_ID = "PageViewServiceActions";
	public static final String PARAM_SERVICE_HASH_CODE = "serviceHash";
	
	private DomainManager domainManager;
	private String subTitle = "ERROR: Subtitle not set";
	private ServiceProxy requestedServiceProxy;
	private boolean isServiceStarted;
	private String html;
	
	public PageViewServiceActions() {
		this.domainManager = Activator.getDomainManager();
	}
	
	@Override
	protected void init() {
		html = "";
		initRequestedServiceProxy(); // TODO: Error handling if requestedServiceProxy is null
		
		subTitle = "Service actions for service " + requestedServiceProxy.getName();
		isServiceStarted = isServiceStarted(requestedServiceProxy);
	}
	
	private boolean isServiceStarted(ServiceProxy serviceProxy) {
		int state = domainManager.getServiceState(serviceProxy.getBundleId());
		return state == Bundle.ACTIVE;
	}
	
	@Override
	protected String getTitle() {
		return SDMServlet.SDM_PAGE_TITLE;
	}

	@Override
	protected String getSubTitle() {
		return subTitle;
	}

	public String getPageId() {
		return PAGE_ID;
	}

	@Override
	protected String getHTMLBody() {
		addStartOrStopLink();
		addUninstallLink();
		html += "Share service<br/>";
		html += "Put in space<br/>";
		addSeeDescriptionLink();
		addEditPropertiesLink();
		html += getGoBackLink();
		return html;
	}

	private void addStartOrStopLink() {
		if (isServiceStarted)
			addStopLink();
		else
			addStartLink();
	}

	private void addStartLink() {
		String pageUrl = getUrlTo(PageStartServiceAction.PAGE_ID);
		String description = "Start service";
		
		addLink(pageUrl, description);
	}

	private void addLink(String url, String description) {
		String link = HTMLBuilder.createAHref(url, description);
		addLine(link);
	}

	private void addLine(String string) {
		html += string + "<br/>";
	}

	private void addStopLink() {
		String pageUrl = getUrlTo(PageStopServiceAction.PAGE_ID);
		String description = "Stop service";
		
		addLink(pageUrl, description);
	}

	private void initRequestedServiceProxy() {
		String hashCodeOfServiceProxy = getHashCodeOfServiceProxy();
		
		if (hashCodeOfServiceProxy == null) {
			serviceProxyHashCodeWasNull();
		} else {
			tryToGetRequestedServiceProxyFrom(hashCodeOfServiceProxy);
		}
	}

	private String getHashCodeOfServiceProxy() {
		HttpServletRequest httpReq = getHttpRequest();
		String hashCodeOfServiceProxy = httpReq.getParameter(PARAM_SERVICE_HASH_CODE);
		return hashCodeOfServiceProxy;
	}

	private void serviceProxyHashCodeWasNull() {
		requestedServiceProxy = ReferencedServices.getLastReferencedServiceProxy();
	}
	
	private void tryToGetRequestedServiceProxyFrom(String hashCodeOfServiceProxy) {
		try {
			getRequestedServiceProxy(hashCodeOfServiceProxy);
		} catch (NoServiceProxyExistsException e) {
			Debug.print("ERROR: Creating EmptyServiceProxy because: " + e.getMessage());
			createEmptyServiceProxy();
		}
	}

	private void getRequestedServiceProxy(String hashCodeOfServiceProxy) {
		requestedServiceProxy =
			ReferencedServices.getReferencedServiceProxyBy(hashCodeOfServiceProxy);
		ReferencedServices.setLastReferencedServiceProxy(requestedServiceProxy);
	}	

	private void createEmptyServiceProxy() {
		requestedServiceProxy = new EmptyServiceProxy();
	}
	
	private String getGoBackLink() {
		String html = "<p><a href='" + getUrlTo(PageMainMenu.PAGE_ID) + "'>" +
			"Go back</a></p>";
		
		return html;
	}

	private void addUninstallLink() {
		String pageUrl = getUrlTo(PageUninstallServiceAction.PAGE_ID);
		String description = "Uninstall service";
		
		addLink(pageUrl, description);
	}
	
	private void addSeeDescriptionLink() {
		String pageUrl = getUrlTo(PageSeeDescriptionAction.PAGE_ID);
		String description = "See description";
		
		addLink(pageUrl, description);
	}
	

	private void addEditPropertiesLink() {
		String pageUrl = getUrlTo(PageEditServiceProperties.PAGE_ID);
		String description = "Edit service properties";
		
		addLink(pageUrl, description);
	}

}
