package org.ubicollab.core.sdm.view.servlet.pages;

import java.util.Collection;

import org.ubicollab.core.sdm.DomainManager;
import org.ubicollab.core.sdm.view.servlet.Activator;
import org.ubicollab.core.sdm.view.servlet.SDMServlet;
import org.ubicollab.core.sm.model.ISpaceManager;
import org.ubicollab.core.sm.model.Space;
import org.ubicollab.service.ServiceProxy;

public class PageViewServicesInPlace extends PageViewServices  {

	public static final String PAGE_ID = "PageViewServicesInPlace";
	public static final String PARAM_SPACE_ID_TO_VIEW = "spaceIdToView";
	
	private DomainManager domainManager;
	private ISpaceManager spaceManager;
	
	public PageViewServicesInPlace() {
		domainManager = Activator.getDomainManager();
		spaceManager = Activator.getSpaceManager();
	}
	
	@Override
	protected String getTitle() {
		return SDMServlet.SDM_PAGE_TITLE;
	}

	@Override
	protected String getSubTitle() {
		return "Viewing services categorized by their place";
	}

	public String getPageId() {
		return PAGE_ID;
	}

	@Override
	protected String getHTMLBody() {
		String strIdOfSpaceToView = getHttpRequest().getParameter(PARAM_SPACE_ID_TO_VIEW);
		
		if (strIdOfSpaceToView == null) {
			String html = "";
			html += "Missing GET parameter for which space to view.";
			html += getGoBackLink();
			return html;
		} else {
			setServicesToView(strIdOfSpaceToView);
			return super.getHTMLBody();
		}
	}


	@Override
	protected String getGoBackLink() {
		String html = "<p><a href='" + getUrlTo(PageCategrByPlace.PAGE_ID) + "'>" +
			"Go back</a></p>";
		
		return html;
	}

	private void setServicesToView(String strIdOfSpaceToView) {
		Space spaceToViewServicesFor = getSpaceFrom(strIdOfSpaceToView);
		
		Collection<ServiceProxy> proxiesToView =
			domainManager.getServicesInSpace(spaceToViewServicesFor);
		
		setServices(proxiesToView);
	}

	private Space getSpaceFrom(String strIdOfSpaceToView) {
		Long idOfSpaceToView = Long.parseLong(strIdOfSpaceToView);
		Space spaceToViewServicesFor = spaceManager.getSpace(idOfSpaceToView);
		
		return spaceToViewServicesFor;
	}

}
