package org.ubicollab.core.sdm.view.servlet.pages;

import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;

import org.ubicollab.core.sdm.view.servlet.Debug;
import org.ubicollab.service.ServiceProxy;
import org.ubicollab.service.exception.NoServiceProxyExistsException;

/* NOTE: This class is not safe to use in a concurrent environment. */
public class ReferencedServices {

	private static HashMap<Integer, ServiceProxy> referencedServices =
		new HashMap<Integer, ServiceProxy>();
	
	private static ServiceProxy lastReferencedServiceProxy;
	
	static void storeServiceReferencesTo(Collection<ServiceProxy> services) {
		Iterator<ServiceProxy> servIter = services.iterator();
		referencedServices.clear(); // no need to keep old references
		
		while (servIter.hasNext()) {
			ServiceProxy currentProxy = servIter.next();
			Integer hashCode = new Integer(currentProxy.hashCode());
			referencedServices.put(hashCode, currentProxy);
		}
		
		Debug.print("storeServiceReferencesTo result = " + referencedServices);
	}

	static ServiceProxy getReferencedServiceProxyBy(String hashCodeOfServiceProxyStr)
	throws NoServiceProxyExistsException
	{
		Integer hashCodeOfServiceProxy = Integer.parseInt(hashCodeOfServiceProxyStr);
		ServiceProxy retrievedServiceProxy = referencedServices.get(hashCodeOfServiceProxy);
		
		if (retrievedServiceProxy == null) {
			throw new NoServiceProxyExistsException("No ServiceProxy with hash code " +
					hashCodeOfServiceProxy + " found");
		} else {
			return retrievedServiceProxy;
		}
	}
	
	static void setLastReferencedServiceProxy(ServiceProxy serviceProxy) {
		lastReferencedServiceProxy = serviceProxy;
	}
	
	static ServiceProxy getLastReferencedServiceProxy() {
		return lastReferencedServiceProxy;
	}
	
}
