package org.ubicollab.core.service.proxy;


/*
 * Handles messages from a ServiceLink and forwards them via HTTP to a remote location.
 */
// TODO: Error handling.

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;

import org.ubicollab.service.ServiceLink;

public class ServiceProxyClient implements ServiceLink {
	private String urlOfRemoteProxy;
	private URLConnection remoteProxyConn;

	public ServiceProxyClient(String urlOfRemoteProxy) {
		this.urlOfRemoteProxy = urlOfRemoteProxy;
	}

	// Usually called on by a ServiceLinkSender that wants to transfer a message to a remote host.
	public String msgReceived(String msg) {
		try {
			sendMessageToProxy(msg);
			return getResponse();
		} catch (MalformedURLException e) {
			Debug.print("Invalid URL.");
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		return "Error: No response";
	}

	private void sendMessageToProxy(String msg)
	throws MalformedURLException, IOException {
		Debug.print("sendMessageToProxy: " + msg);
		String msgUrl = getMsgUrl(msg);
		openUrl(msgUrl);
	}

	private String getMsgUrl(String msg) throws UnsupportedEncodingException {
		String endUrl = "?" + ServiceProxyServerServlet.KEY_PROXY_MSG + "=" + msg;
		endUrl = urlEncode(endUrl);
		String msgUrl = urlOfRemoteProxy + endUrl;
		return msgUrl;
	}

	private void openUrl(String url) throws MalformedURLException,
			IOException {
		URL remoteProxyUrl = new URL(url);
		remoteProxyConn = remoteProxyUrl.openConnection();
	}

	private String urlEncode(String msgUrl) throws UnsupportedEncodingException {
		return msgUrl.replace(" ", "%20");
	}
	
	private String getResponse() throws IOException {
		String htmlResponse = getHtmlResponse();
		
		if (htmlResponse == null) {
			Debug.print("ERROR: Response from PptViewer host application was null");
			throw new RuntimeException(
			"Response from PptViewer host application was null");
		}
		
		String response = extractResponseFromHtml(htmlResponse);
		return response;
	}

	private String getHtmlResponse() throws IOException {
		BufferedReader responseReader = new BufferedReader(
				new InputStreamReader(remoteProxyConn.getInputStream()));
		String htmlResponse = getHtmlResponseAsOneLine(responseReader);
		responseReader.close();
		
		return htmlResponse;
	}

	private String getHtmlResponseAsOneLine(BufferedReader responseReader)
	throws IOException {
		String htmlResponse = "";
		String line;

		while ((line = responseReader.readLine()) != null) {
			htmlResponse += line; 
		}

		return htmlResponse;
	}

	private String extractResponseFromHtml(String htmlResponse) {
		String responseTag = ServiceProxyServerServlet.KEY_RESPONSE + "=";
		int startIndex = htmlResponse.indexOf(responseTag) + responseTag.length();
		int endIndex = htmlResponse.indexOf("</html>");
		String response = htmlResponse.substring(startIndex, endIndex);
		
		return response;
	}


}
