package org.ubicollab.core.service.proxy;

/*
 * Handles incoming HTTP requests and forwards them to a ServiceLinkSender.
 */

import javax.servlet.ServletException;

import org.osgi.framework.BundleContext;
import org.osgi.service.http.HttpService;
import org.osgi.service.http.NamespaceException;
import org.osgi.util.tracker.ServiceTracker;
import org.ubicollab.service.Debug;
import org.ubicollab.service.ServiceLink;

public class ServiceProxyServer implements ServiceLink {
	private ServiceLink serviceLink;
	private ServiceProxyServerServlet proxyServlet;
	private String servletAlias;
	
	private boolean isRegisteredInOsgi;

	private ServiceTracker httpTracker;
	private HttpService httpService = null;

	public ServiceProxyServer(ServiceLink serviceLink, String servletAlias) {
		this.serviceLink = serviceLink;
		this.servletAlias = servletAlias;
		
		isRegisteredInOsgi = false;
		proxyServlet = new ServiceProxyServerServlet(this);
	}

	public void start(BundleContext bundleContext) {
		createHttpServlet(bundleContext);
		Debug.print("Service proxy started.");
	}

	public void createHttpServlet(BundleContext bundleContext) {
		// Create HttpService tracker
		httpTracker = new ServiceTracker(bundleContext, HttpService.class.getName(), null);
		httpTracker.open();
		httpService = (HttpService) httpTracker.getService();
		if (httpService != null) {
			// Register the servlet in the HTTP Service
			try {
				httpService.registerServlet(
						getServletAlias(), proxyServlet, null, null);
				isRegisteredInOsgi = true;
				Debug.print("Servlet registered with alias " + servletAlias);
			} catch (ServletException e) {
				Debug.print("ERROR: if the servlet's init method throws an exception," +
						"or the given servlet object has already been registered at a" +
						"different alias.");
				e.printStackTrace();
			} catch (NamespaceException e) {
				Debug.print("ERROR: Alias already in use!");
				e.printStackTrace();
			}
		} else {
			Debug.print("ERROR: httpService was null!!");
		}
	}

	public void stop() {
		unregisterHttpServlet();
		Debug.print("Service proxy stopped.");
	}
	
	public void unregisterHttpServlet() {
		if (httpService != null) {
			try {
				httpService.unregister(getServletAlias());
				isRegisteredInOsgi = false;
			} catch (IllegalArgumentException e) {
				e.printStackTrace();
			}
		}

		if (httpTracker != null) {
			httpTracker.close();
		}
	}
	
	private String getServletAlias() {
		return "/" + servletAlias;
	}

	public boolean isRunning() {
		return isRegisteredInOsgi;
	}

	public String msgReceived(String proxyMsg) {
		return serviceLink.msgReceived(proxyMsg);
	}

}
