package org.ubicollab.core.service.proxy;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.ubicollab.service.Debug;
import org.ubicollab.service.ServiceLink;

@SuppressWarnings("serial")
public class ServiceProxyServerServlet extends HttpServlet {
	public static final String KEY_PROXY_MSG = "proxyMsg";
	public static final String KEY_RESPONSE = "response";

	private ServiceLink serviceLink;
	
	public ServiceProxyServerServlet(ServiceLink serviceLink) {
		this.serviceLink = serviceLink;
	}
	
	// Handles incomming messages from other ServiceLinkProxy-s.
	protected void doGet(HttpServletRequest req, HttpServletResponse resp) {
		Debug.print("Incoming request.");
		String proxyMsg = readProxyMsgFrom(req);
		String reply;
		if (proxyMsg == null) {
			Debug.print("ProxyMsg was null, returning standard reply.");
			reply = "You must enter a message.";
		} else {
			reply = serviceLink.msgReceived(proxyMsg);
		}
		writeHttpResponse(resp, reply);
	}

	private String readProxyMsgFrom(HttpServletRequest req) {
		String proxyMsg = req.getParameter(KEY_PROXY_MSG);
		Debug.print("proxyMsg = " + proxyMsg);
		return proxyMsg;
	}

	private void writeHttpResponse(HttpServletResponse httpResponse,
			String response) {
		String htmlResponse = buildHtmlResponseFrom(response);
		PrintWriter httpResponseWriter = getHttpResponseWriter(httpResponse);
		httpResponseWriter.print(htmlResponse);
		httpResponseWriter.close();
	}
	
	private String buildHtmlResponseFrom(String reply) {
		String htmlResponse = "<html>" + KEY_RESPONSE + "=" + reply + "</html>";
		return htmlResponse;
	}
	
	private PrintWriter getHttpResponseWriter(HttpServletResponse httpResponse) {
		httpResponse.setContentType("text/html");
		
		// Get the Writer AFTER setContentType - this ensures that
		// the obtained writer will property perform character set conversion.
		// Produce a HTML page according to the request.
		try {
			PrintWriter httpResponseWriter = httpResponse.getWriter();
			return httpResponseWriter;
		} catch (IOException e) {
			e.printStackTrace();
			throw new RuntimeException("Could not get httpRseponseWriter.");
		}
		
	}
}
