package org.ubicollab.service;
import java.util.Properties;

import org.ubicollab.core.sm.model.Space;

/*
 * A Service is what in Ubicollab terminology is called a Service Proxy. A Service Proxy
 * is in turn a OSGi Bundle. A Service Proxy, however, is a subset of a OSGi Bundle, that
 * is to be used in the Ubicollab domain/setting. This means that this Service class
 * has some properties and methods that is needed for the concept Service Proxy.
 */
public interface ServiceProxy {
	/**
	 *
	 */
	Properties getOsgiPropertiesForUbicollabServices();
	
	/**
	 * Gets the human readable name of the service.
	 * 
	 * @return The human readable name of the service.
	 */
	String getName();
	
	/**
	 * @return The ServiceLink of this Service.
	 */
	ServiceLink getServiceLink();
	
	/**
	 * @param serviceLink The ServiceLink to set.
	 */
	void setServiceLink(ServiceLink serviceLink);
	
	/**
	 * Sets the name attribute of the service.
	 * 
	 * @param name the name attribute of the service
	 */
	void setName(String name);
	
	/**
	 * Gets the service URI attribute of the service.
	 * 
	 * @return the service URI attribute of the service
	 */
	String getServiceURI();
	
	/**
	 * Sets the service URI attribute of the service.
	 * 
	 * @param serviceURI the service URI attribute of the service
	 */
	void setServiceURI(String serviceURI);
	
	/**
	 * Gets the space attribute of the service.
	 * 
	 * @return the space attribute of the service
	 */
	Space getSpace();
	
	/**
	 * Sets the space attribute of the service.
	 * 
	 * @param space the space attribute of the service
	 */
	void setSpace(Space space);

	/**
	 * Gets the type attribute of the service.
	 * 
	 * @return the type attribute of the service
	 */
	ServiceType getType();


	/**
	 * Sets the type attribute of the service.
	 * 
	 * @param type the type attribute of the service
	 */
	void setType(ServiceType type);


	/**
	 * Gets the description attribute of the service.
	 * 
	 * @return the description
	 */
	String getDescription();


	/**
	 * Sets the description attribute of the service.
	 * 
	 * @param description the description
	 */
	void setDescription(String description);
	
	/**
	 * Gets the bundle ID attribute of the service.
	 * 
	 * @return the bundle ID attribute of the service
	 */
	long getBundleId();

	/**
	 * Gets the XML represenatation for the service.
	 * 
	 * @param state the state of the service
	 * 
	 * @return the XML representing the service
	 */
	String toXML(String bundleState);
}
