package org.ubicollab.service;

import org.osgi.framework.Bundle;
import org.ubicollab.core.sm.model.Space;

public class ServiceProxyFactory {
	/**
	 * A string used in Bundle-SymbolicName used to identify a OSGi Bundle as a Ubicollab service.
	 **/
	public final static String SYMBOLIC_NAME_FOR_UBICOLLAB_SERVICES = "org.ubicollab.service";

	/**
	 * The name of a property identifying the type of a Ubicollab service.
	 **/
	public final static String SERVICE_NAME_PROPERTY_NAME = "Bundle-Name";

	/**
	 * The name of a property identifying the type of a Ubicollab service.
	 **/
	public final static String SERVICE_DESCRIPTION_PROPERTY_NAME = "Bundle-Description";

	/**
	 * The name of a property identifying the type of a Ubicollab service.
	 **/
	public final static String SERVICE_TYPE_PROPERTY_NAME = "Ubicollab-Service-Type";
	
	private static Bundle bundle;
	private static Space defaultSpace = new Space();
	
	public static ServiceProxy createUbicollabServiceFrom(Bundle bundle) {
		ServiceProxyFactory.bundle = bundle;
		
		String friendlyName = getHeader(
				ServiceProxyFactory.SERVICE_NAME_PROPERTY_NAME, "No name set");
		String serviceUri = bundle.getLocation();
		Space collaborationSpace = defaultSpace;
		long bundleId = bundle.getBundleId();
		String description = getHeader(
				ServiceProxyFactory.SERVICE_DESCRIPTION_PROPERTY_NAME, "No description set");
		String serviceTypeName = getHeader(
				ServiceProxyFactory.SERVICE_TYPE_PROPERTY_NAME, "NoTypeSet");
		ServiceType serviceType = new ServiceType(serviceTypeName);
		
		ServiceProxy ubiService = new ServiceProxyImpl(
				friendlyName,
				serviceUri,
				collaborationSpace,
				bundleId,
				serviceType,
				description
				);
		
		return ubiService;
	}

	private static String getHeader(String headerName, String headerValueIfHeaderDoesntExist) {
		Object dictValue = bundle.getHeaders().get(headerName);
		
		if (dictValue == null)
			return headerValueIfHeaderDoesntExist;
		else
			return dictValue.toString();
	}


}
