package org.ubicollab.service;

import java.util.Properties;

import org.ubicollab.core.sm.model.Space;


/**
 * The <code>Service</code> Class is intended to store information about proxy 
 * services in UbiCollab.
 */
public class ServiceProxyImpl implements ServiceProxy {

	private static final String TOSTRING_PREFIX = "ubiService_";
	 
	private String name; // The name of the service.
	private String serviceUri;
	private ServiceType type; // The service type.
	private Space collaborationSpace; // The UbiCollab Collaboration Space.
	private long bundleId;
	private String description;
	private ServiceLink serviceLink;	

	/**
	 * Constructor for creating a Service object and setting the variables at the same time.
	 * 
	 * @param space the Space this service is located in
	 * @param collaborationSpace the name of the space
	 * @param name the name
	 * @param bundleId the bundle ID
	 * @param serviceUri the service URI
	 * @param type the service type
	 * @param description a textual description of the service
	 */
	public ServiceProxyImpl(String name, String serviceUri, Space collaborationSpace,
			long bundleId, ServiceType type, String description) {
		this.name = name;
		this.serviceUri = serviceUri;
		this.collaborationSpace = collaborationSpace;
		this.bundleId = bundleId;
		this.type = type;
		this.description = description;

	}

	public String toXML(String state) {
		String xml = "<Service ";
		xml += "Id='" + getBundleId() + "' ";
		xml += "ServiceUri='" + getServiceURI() + "' ";
		xml += "Name='" + getName() + "' ";
		xml += "Space='" + getSpace() + "' ";
		xml += "State='" + state + "' ";
		xml += "Type='" + getType() + "' ";
		xml += "Description='" + getDescription() + "' />";
		return xml;
	}
	
	public long getBundleId() {
		return bundleId;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public void setServiceLink(ServiceLink serviceLink) {
		this.serviceLink = serviceLink;
	}
	
	public ServiceLink getServiceLink() {
		return serviceLink;
	}

	public String getServiceURI() {
		return serviceUri;
	}

	public void setServiceURI(String serviceURI) {
		this.serviceUri = serviceURI;
	}
	
	public Space getSpace() {
		return collaborationSpace;
	}

	public void setSpace(Space space) {
		this.collaborationSpace = space;
	}

	public ServiceType getType() {
		return type;
	}

	public void setType(ServiceType type) {
		this.type = type;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}
	
	public String toString() {
		return TOSTRING_PREFIX + getBundleId() + "_" + getName();
	}
	
	/*
	 * Returns Properties used for -OSGi services- that should be identified as a Ubicollab service.
	 * NOTE: There are some overlap between OSGi service and a OSGi bundle in the current
	 * design/concept of the DomainManager. An Ubicollab service is the same as a bundle, and is in
	 * Ubicollab terminology called a service, or a service proxy. This method returns a
	 * Properties object that will, if used when registering a OSGi service, identify the OSGi
	 * service as a Ubicollab service. In other words, the properties will connect a OSGi service
	 * to a OSGi bundle (the Ubicollab service).
	 * 
	 * With the current implementation, this is neccessary if the DomainManager should be able to
	 * find the Ubicollab service (i.e. the OSGi bundle) and add the service to its ServiceList. 
	*/
	public Properties getOsgiPropertiesForUbicollabServices() {
		Properties defaultOsgiServiceProperties = new Properties();
		// Identify the service as a Ubicollab service.
		/*
		defaultOsgiServiceProperties.put(OSGI_SERVICES_TYPE_PROPERTY, OSGI_SERVICES_TYPE_VALUE);
		// Set a human readable name for this service.
		defaultOsgiServiceProperties.put(SERVICE_NAME_PROPERTY, getName());
		*/
		return defaultOsgiServiceProperties;
	}


}
