package org.ubicollab.service.settings;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Enumeration;
import java.util.InvalidPropertiesFormatException;
import java.util.Properties;

import org.ubicollab.service.exception.InvalidXMLException;

public class ServiceSettings {
	private Properties settings;
	
	public ServiceSettings() {
		settings = new Properties();
	}
	
	public ServiceSettings(String xml) throws InvalidXMLException {
		settings = new Properties();
		initPropertiesFrom(xml);
	}

	private void initPropertiesFrom(String xml) throws InvalidXMLException {
		byte[] bytes = xml.getBytes();
		InputStream inputStream = new ByteArrayInputStream(bytes);
		try {
			settings.loadFromXML(inputStream);
		} catch (InvalidPropertiesFormatException e) {
			throw new InvalidXMLException("ServiceSettings could not be made from XML: " + xml);
		} catch (IOException e) {
			throw new InvalidXMLException("ServiceSettings could not be made from XML: " + xml);
		}
	}

	public Enumeration<?> getElements() {
		return settings.propertyNames();
	}
	
	public void set(String key, String value) {
		settings.put(key, value);
	}
	
	public String get(String key) {
		return settings.getProperty(key);
	}
	
	public String toXml() throws IOException {
		OutputStream outStream = new ByteArrayOutputStream();
		String noComment = "";
		settings.storeToXML(outStream, noComment);
		return outStream.toString();
	}
}
