package org.ubicollab.testing.sdm.junit;

import java.io.IOException;
import java.net.MalformedURLException;
import java.util.ArrayList;
import java.util.Iterator;

import junit.framework.TestSuite;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.BundleException;
import org.osgi.util.tracker.ServiceTracker;
import org.ubicollab.core.sdm.DomainManager;
import org.ubicollab.service.ServiceProxy;
import org.ubicollab.service.ServiceProxyFinder;

/**
 * Registers JUnit tests for testing org.ubicollab.core.sdm.
 * 
 * @author Yngvar Kristiansen
 *
 */
public class Activator implements BundleActivator {
	// The bundle used for all tests.
	private static final String urlToHelloWorldbundle =
		"http://yngvark.com/files/HelloWorldUbicollab.jar";
	
	public static BundleContext bundleContext;
	protected static DomainManager domainManager = null;
	
	private static Activator activatorInstance;
	private long helloWorldBundleId;
	
	/* (non-Javadoc)
	 * @see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
	 */
	public void start(BundleContext bundleContext) throws Exception {
		Activator.bundleContext = bundleContext;
		Activator.activatorInstance = this;
		try {
			domainManager = getDomainManager();
			helloWorldBundleId = initHelloWorldBundle();
			createTests();
		} catch (Exception e) {
			Debug.print("Error in test setup!");
			e.printStackTrace();
		}
		
	    Debug.print("Ready.");
	}
	
	private void createTests() {
		// The reason for having 2 test suites is to be able to run a subset of the tests in stead
		// of all the tests (which takes a bit of time).
		
		TestSuite testSuite = createTestSuite();
		createOsgiJunitTest(testSuite, "org.ubicollab.testing.sdm.junit");
		
		TestSuite testSuite2 = createTestSuite2();
		createOsgiJunitTest(testSuite2, "org.ubicollab.testing.sdm.junit2");
	}

	private TestSuite createTestSuite() {
		TestSuite testSuite = new TestSuite(DomainManagerTest.class);
		return testSuite;
	}
	
	private TestSuite createTestSuite2() {
		TestSuite testSuite = new TestSuite(DomainManagerTest2.class);
		return testSuite;
	}

	private void createOsgiJunitTest(TestSuite testSuite, String testName) {
		OsgiJunitTest osgiJunitTest = new OsgiJunitTest(bundleContext);
		osgiJunitTest.registerTestAsOSGiService(testSuite, testName);
	}

	private DomainManager getDomainManager() {
		DomainManager domainManager =
			(DomainManager) getOsgiService(DomainManager.class.getName());
		return domainManager;
	}

	private Object getOsgiService(String className) {
		ServiceTracker serviceListTracker = getServiceTracker(className);
		Object serviceInstance = serviceListTracker.getService();
		
		return serviceInstance; 
	}

	private ServiceTracker getServiceTracker(String className) {
		ServiceTracker serviceListTracker = new ServiceTracker(bundleContext, className, null);
		serviceListTracker.open();
		
		return serviceListTracker;
	}

	private Long initHelloWorldBundle() throws MalformedURLException,
			BundleException, InterruptedException, IOException {

		// lag try som behandler hvis helloworld ikke finnes
		Long helloWorldBundleId;
		try {
			helloWorldBundleId = searchForHelloWorldTestBundleId();
		} catch (HelloWorldBundleNotFoundException e) {
			helloWorldBundleId = installHelloWorldBundle();
		}

		return helloWorldBundleId;

	}
	
	private Long searchForHelloWorldTestBundleId()
	throws HelloWorldBundleNotFoundException
	{
		ArrayList<ServiceProxy> proxies =
			ServiceProxyFinder.searchForUbicollabServices(bundleContext);
		
		Iterator<ServiceProxy> iter = proxies.iterator();
		while (iter.hasNext()) {
			ServiceProxy proxy = iter.next();
			if (proxyIsHelloWorldProxy(proxy)) {
				return proxy.getBundleId();
			}
		}

		throw new HelloWorldBundleNotFoundException("Hello world bundle not found");
	}
	
	private boolean proxyIsHelloWorldProxy(ServiceProxy proxy) {
		return proxy.getName().equals("HelloWorldUbicollab");
	}

	private long installHelloWorldBundle()
	throws MalformedURLException, BundleException, InterruptedException, IOException
	{
		long installedBundleId = domainManager.installService(urlToHelloWorldbundle);
		return installedBundleId;
	}

	/* (non-Javadoc)
	 * @see org.osgi.framework.BundleActivator#stop(org.osgi.framework.BundleContext)
	 */
	public void stop(BundleContext context) throws Exception {
		// OSGi automatiacally unregisters any OSGi services made by this bundle (the osgi tests,
		// that is).
		Debug.print("Stopped");
	}

	public long getHelloWorldBundle() {
		return helloWorldBundleId;
	}

	public static Activator getInstance() {
		return activatorInstance; 
	}


}
