package org.ubicollab.testing.sdm.junit;

import java.io.IOException;
import java.util.Collection;

import junit.framework.TestCase;

import org.osgi.framework.BundleException;
import org.ubicollab.core.sdm.DomainManager;
import org.ubicollab.core.sm.model.Space;
import org.ubicollab.service.ServiceProxy;
import org.ubicollab.service.ServiceType;

public class DomainManagerTest2 extends TestCase {

	// Bundles required for testSetActiveSpace
	private static final String urlToHelloWorldbundle2 =
		"http://yngvark.com/files/HelloWorldUbicollab2.jar";
	private static final String urlToHelloWorldbundle3 =
		"http://yngvark.com/files/HelloWorldUbicollab3.jar";
	
	private DomainManager domainManager;
	private long helloWorldBundleId;

	public DomainManagerTest2() {
		helloWorldBundleId = Activator.getInstance().getHelloWorldBundle(); 
		domainManager = Activator.domainManager;
	}
	
	public void testGetServicesInSpace() throws BundleException, IOException {
		Debug.print("testGetServicesInSpace");
		long bundleIdHw2 = domainManager.installService(urlToHelloWorldbundle2);
		domainManager.startService(bundleIdHw2);
		long bundleIdHw3 = domainManager.installService(urlToHelloWorldbundle3);
		domainManager.startService(bundleIdHw3);
		
		ServiceProxy testProxy = domainManager.getServices(bundleIdHw2);
		ServiceProxy testProxy2 = domainManager.getServices(bundleIdHw3);		
		
		Space plaza = new Space();
		testProxy.setSpace(plaza);
		testProxy2.setSpace(plaza);
		
		// Now, check that domainManager.getServicesInSpace(plaza) contains the two services, and
		// only those two services.
		Collection<ServiceProxy> proxiesInSpace = domainManager.getServicesInSpace(plaza);
		Debug.print("proxiesInSpace = " + proxiesInSpace);
		assertTrue("testProxy wasn't found in list of proxies",
				proxiesInSpace.contains(testProxy));
		assertTrue("testProxy2 wasn't found in list of proxies",
				proxiesInSpace.contains(testProxy2));
		assertEquals(2, proxiesInSpace.size());
		
		domainManager.removeService(bundleIdHw2);
		domainManager.removeService(bundleIdHw3);
	}
	
	public void testGetServicesWithType() throws BundleException, IOException {
		Debug.print("testGetServicesWithType");
		
		long bundleIdHw2 = domainManager.installService(urlToHelloWorldbundle2);
		domainManager.startService(bundleIdHw2);
		long bundleIdHw3 = domainManager.installService(urlToHelloWorldbundle3);
		domainManager.startService(bundleIdHw3);
		
		ServiceProxy testProxy = domainManager.getServices(bundleIdHw2);
		ServiceProxy testProxy2 = domainManager.getServices(bundleIdHw3);	
		
		ServiceType red = new ServiceType("critical");
		testProxy.setType(red);
		testProxy2.setType(red);
		
		// Now, check that domainManager.getServicesWithType(critical) contains the two services,
		// and only those two services.
		Collection<ServiceProxy> proxiesInSpace = domainManager.getServicesWithType(red);
		Debug.print("proxiesInSpace = " + proxiesInSpace);
		assertTrue("testProxy wasn't found in list of proxies",
				proxiesInSpace.contains(testProxy));
		assertTrue("testProxy2 wasn't found in list of proxies",
				proxiesInSpace.contains(testProxy2));
		assertEquals(2, proxiesInSpace.size());
		
		domainManager.removeService(bundleIdHw2);
		domainManager.removeService(bundleIdHw3);
	}
	
	public void testGetServiceTypeByName() throws BundleException, IOException {
		Debug.print("testGetServiceTypeByName");
		
		long bundleIdHw2 = domainManager.installService(urlToHelloWorldbundle2);
		domainManager.startService(bundleIdHw2);

		ServiceProxy testProxy = domainManager.getServices(bundleIdHw2);

		String blueTypeName = "blue_23423424367";
		ServiceType blue = new ServiceType("blue_23423424367");
		testProxy.setType(blue);
		
		// DomainManager should now be able to retrieve the blue ServiceType given it's name.
		ServiceType retrievedServiceType = domainManager.getServiceTypeByName(blueTypeName);
		assertEquals(retrievedServiceType, blue);
		
		domainManager.removeService(bundleIdHw2);
	}
}
