package org.ubicollab.view.servlet;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;


public class LinkedHTMLPageFactory implements HTMLPageFactory {
	private HashMap<String, HTMLPage> pageRoutings;
	
	public LinkedHTMLPageFactory() {
		this.pageRoutings = new HashMap<String, HTMLPage>();
	}
		
	public HTMLPage getHtmlPage(HttpServletRequest req) {
		HTMLPage page;
		if (req.getMethod().equals("GET")) {
			page = getPageFromHttpGetMethod(req);
		} else if (req.getMethod().equals("POST")) {
			page = new PageError("POST not implemented yet");
		} else {
			page = new PageError("HTTP request wasn't GET or POST");
		}
		
		page.setHttpRequest(req);
		
		return page;
	}

	private HTMLPage getPageFromHttpGetMethod(HttpServletRequest req) {
		String requestedPageId = req.getParameter(GUIServlet.PAGE_PARAM_NAME);
		return getPageFrom(requestedPageId);
	}
	
	private HTMLPage getPageFrom(String requestedPageId) {
		HTMLPage page = null;
		if (requestedPageId == null) {
			page = new PageError("No page requested.");
		} else {
			page = getRoutingFromPageIdToHtmlPage(requestedPageId);
		}
		
		if (page == null) {
			page = new PageError("No page associated with request.");
		}
		return page;
	}
	
	
	
	public void setRoutingFromPageIdToHtmlPage(String pageId, HTMLPage htmlPage) {
		pageRoutings.put(pageId, htmlPage);
	}
	
	public HTMLPage getRoutingFromPageIdToHtmlPage(String pageId) {
		return pageRoutings.get(pageId);
	}

}
