<?php
/*
 * ------------------------------------------------------------------------------------------------
 * DESCRIPTION:
 * This class is able to convert a PPT from a given URL and show it in a web page.
 * ------------------------------------------------------------------------------------------------
 * DEPENDENCIES:
 * ImageBrowser.php, which should come along this file.
 * PptConverter.php, which should come along this file.
 *
 * 1) Check settings in Config.php
 *
 * 2) Fullfill requirements in PptConverter.php and ImageBrowser.php.
 * ------------------------------------------------------------------------------------------------
 * HOW TO RUN:
 * 1) Put the following content in your entry PHP file, for instance index.php:
 * "
 * require_once("PptViewer.php");
 * $pptViewer = new PptViewer();
 * $pptViewer->handleRequest($_GET);
 * "
 *
 * 2) Then, open the following URL in a browser (given your script name is index.php):
 * index.php?action=viewPpt&url=http://yngvark.com/files/MSIS.ppt
 * ------------------------------------------------------------------------------------------------
 *
 * Yngvar Kristiansen, 11.05.2010
*/

require_once('Config.php');
require_once('PptConverter.php');
require_once('ErrorController.php');
require_once('HtmlPageBuilder.php');

class PptViewer {
	private $errorCtrl;
	private $htmlPageBuilder;
	
	public function PptViewer() {
		$this->errorCtrl = ErrorController::getInstance();
		$this->htmlPageBuilder = new HtmlPageBuilder();
	}
	
	/**
	 * @param Associative array, such as $_GET or $_POST.
	*/
	public function handleRequest($requestArr) {
		$action = $this->getParam($requestArr, 'action');
		
		if ($action === 'viewPpt') {
			$urlToSrcPpt = $this->getParam($requestArr, 'url');
			$this->viewPpt($urlToSrcPpt);
		} else {
			$this->errorCtrl->addError("Missing paramaters. See this source file for usage.");
		}
		
		if ($this->errorCtrl->isErrors()) {
			$this->errorOccured();
			return;
		}
	} 
	
	private function getParam($requestArr, $param) {
		if (empty($requestArr[$param])) {
			return false;
		}
		
		return $requestArr[$param];
	}
	
	private function viewPpt($urlToSrcPpt) {
		$imgDir = $this->convertPptToImages($urlToSrcPpt);
		
		if ($this->errorCtrl->isErrors()) {
			$this->errorOccured();
			return;
		}
		
		$this->redirectClientToImageBrowser($imgDir);
	}
	
	private function convertPptToImages($urlToSrcPpt) {
		$pptConverter = new PptConverter();
		$imgDir = $pptConverter->convertPptToImages($urlToSrcPpt);
		return $imgDir;
	}
	
	// --------------------------------------------------------------------------------------------
	// FUNCTIONS THAT GENERATE HTML OUTPUT
	// --------------------------------------------------------------------------------------------
	
	private function errorOccured() {
		echo $this->errorCtrl->getErrorsAsHtml();
	}
	
	private function redirectClientToImageBrowser($imgDir) {
		$this->htmlPageBuilder->setBodyEncapsulation(false);
		$this->htmlPageBuilder->addHtml("<head>");
		// Must use meta refresh. Do not use php header('Location: X), as clients expect a HTML based redirect.
		$this->htmlPageBuilder->addHtml(
			"<meta http-equiv='refresh' content='0;url=" .
			Config::URL_TO_IMAGEBROWSER_PHP() .
			"?imgDir=" . $imgDir . "&imgNum=1&isClient=true' />"
			);
		$this->htmlPageBuilder->addHtml("</head>");
		
		echo $this->htmlPageBuilder->getHtmlPage();
	}
}